@@ -1,11 +1,12 @@
-'''
+"""
 Copyright (c) 2021, Saurabh Pujari
 All rights reserved.
 
 This source code is licensed under the BSD-style license found in the LICENSE file in the root directory of this source tree.
-'''
+"""
+
+# Add all custom exception classes here
 
-# Add all custom exception classes here 
 
 class FileAccessError(Exception):
     def __init__(self, message):
@@ -13,7 +14,8 @@ class FileAccessError(Exception):
         super().__init__(self.message)
 
     def __str__(self):
-        return f'Error -> {self.message}'
+        return f"Error -> {self.message}"
+
 
 class FileKeyError(Exception):
     def __init__(self, message):
@@ -21,4 +23,4 @@ class FileKeyError(Exception):
         super().__init__(self.message)
 
     def __str__(self):
-        return f'Error -> {self.message}'
\ No newline at end of file
+        return f"Error -> {self.message}"
